@@ -198,7 +198,8 @@ class Game:
                 "text": t("Select game data"),
                 "callback": self.handle_menu_browse_files,
                 "cond": lambda: (self.menu_state == "config"
-                                 and not self.menu.browse_files),
+                                 and not self.menu.browse_files
+                                 and not self.config.disable_change_resources_dir),
                 "secondary": True,
             },
             {
